Struct rustdoc::clean::ArgumentsUnstable
[-] [+]
[src]
pub struct Arguments {
pub values: Vec<Argument>,
}Fields
values |
pub struct Arguments {
pub values: Vec<Argument>,
}values |
impl Display for Argumentsimpl Debug for Argumentsimpl PartialEq for Argumentsimpl Decodable for Argumentsimpl Encodable for Argumentsimpl Clone for Argumentsfn clone(&self) -> Argumentsfn clone_from(&mut self, source: &Self)
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).