Struct rustdoc::clean::ConstantUnstable
[-] [+]
[src]
pub struct Constant {
pub type_: Type,
pub expr: String,
}Fields
type_ | |
expr |
pub struct Constant {
pub type_: Type,
pub expr: String,
}type_ | |
expr |
impl Debug for Constantimpl Decodable for Constantimpl Encodable for Constantimpl Clone for Constantfn clone(&self) -> Constantfn clone_from(&mut self, source: &Self)
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).