Struct rustdoc::clean::LifetimeUnstable
[-] [+]
[src]
pub struct Lifetime(_);
pub struct Lifetime(_);
impl Lifetimeimpl Display for Lifetimeimpl Debug for Lifetimeimpl PartialEq for Lifetimeimpl Decodable for Lifetimeimpl Encodable for Lifetimeimpl Clone for Lifetimefn clone(&self) -> Lifetimefn clone_from(&mut self, source: &Self)
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).