Struct rustdoc::clean::MacroUnstable
[-] [+]
[src]
pub struct Macro {
pub source: String,
}Fields
source |
pub struct Macro {
pub source: String,
}source |
impl Debug for Macroimpl Decodable for Macroimpl Encodable for Macroimpl Clone for Macrofn clone(&self) -> Macrofn clone_from(&mut self, source: &Self)
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).