Struct rustdoc::clean::PathUnstable
[-] [+]
[src]
pub struct Path {
pub global: bool,
pub segments: Vec<PathSegment>,
}Fields
global | |
segments |
pub struct Path {
pub global: bool,
pub segments: Vec<PathSegment>,
}global | |
segments |
impl Pathimpl Display for Pathimpl Debug for Pathimpl PartialEq for Pathimpl Decodable for Pathimpl Encodable for Pathimpl Clone for Pathfn clone(&self) -> Pathfn clone_from(&mut self, source: &Self)
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).