Struct rustdoc::clean::VariantUnstable
[-] [+]
[src]
pub struct Variant {
pub kind: VariantKind,
}Fields
kind |
pub struct Variant {
pub kind: VariantKind,
}kind |
impl Debug for Variantimpl Decodable for Variantimpl Encodable for Variantimpl Clone for Variantfn clone(&self) -> Variantfn clone_from(&mut self, source: &Self)
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).